package com.dgtly.member.mapper;

import com.dgtly.member.domain.MemberInfo;
import java.util.List;

/**
 * 会员信息Mapper接口
 * 
 * @author dgtly
 * @date 2020-02-13
 */
public interface MemberInfoMapper 
{
    /**
     * 查询会员信息
     * 
     * @param id 会员信息ID
     * @return 会员信息
     */
    public MemberInfo selectMemberInfoById(Long id);

    /**
     * 查询会员信息列表
     * 
     * @param memberInfo 会员信息
     * @return 会员信息集合
     */
    public List<MemberInfo> selectMemberInfoList(MemberInfo memberInfo);

    /**
     * 新增会员信息
     * 
     * @param memberInfo 会员信息
     * @return 结果
     */
    public int insertMemberInfo(MemberInfo memberInfo);

    /**
     * 修改会员信息
     * 
     * @param memberInfo 会员信息
     * @return 结果
     */
    public int updateMemberInfo(MemberInfo memberInfo);

    /**
     * 删除会员信息
     * 
     * @param id 会员信息ID
     * @return 结果
     */
    public int deleteMemberInfoById(Long id);

    /**
     * 批量删除会员信息
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteMemberInfoByIds(String[] ids);


    /**
     * @descption: 检测登录账号的唯一性
     * @param: 登录账号
     * @return: 会员实体
     * @auther: LiuLingChao
     * @date: 2020-2-25 15:12
     */
    public MemberInfo checkMemberUnique(String loginAccount);
    /**
     * @descption: 检测手机号的唯一性
     * @param: 手机号
     * @return: 会员实体
     * @auther: LiuLingChao
     * @date: 2020-2-25 15:12
     */
    public MemberInfo checkMemberPhoneUnique(String phone);


    /**
     * @descption: 用户登录
     * @param: 登录账号/手机号、密码
     * @return:
     * @auther: LiuLingChao
     * @date: 2020-2-25 15:39
     */
    public MemberInfo memberLogin(MemberInfo memberInfo);
}
